(define
  (domain roverdom--s859466--m25--r2--w3--o2--c2--g2--p0--P1--Z200--X200--C10)
  (:requirements :typing)
  (:types rover waypoint store camera mode lander objective road)
  (:predicates
    (at ?x - rover ?y - waypoint)
    (at_lander ?x - lander ?y - waypoint)
    (can_traverse ?r - rover ?x - waypoint ?y - waypoint)
    (equipped_for_soil_analysis ?r - rover)
    (equipped_for_rock_analysis ?r - rover)
    (equipped_for_imaging ?r - rover)
    (empty ?s - store)
    (have_rock_analysis ?r - rover ?w - waypoint)
    (have_soil_analysis ?r - rover ?w - waypoint)
    (full ?s - store)
    (calibrated ?c - camera ?r - rover)
    (supports ?c - camera ?m - mode)
    (available ?r - rover)
    (visible ?w - waypoint ?p - waypoint)
    (have_image ?r - rover ?o - objective ?m - mode)
    (communicated_soil_data ?w - waypoint)
    (communicated_rock_data ?w - waypoint)
    (communicated_image_data ?o - objective ?m - mode)
    (at_soil_sample ?w - waypoint)
    (at_rock_sample ?w - waypoint)
    (visible_from ?o - objective ?w - waypoint)
    (store_of ?s - store ?r - rover)
    (calibration_target ?i - camera ?o - objective)
    (on_board ?i - camera ?r - rover)
    (channel_free ?l - lander)
    (road_isunknown ?r - road)
    (road_isfree ?r - road)
    (road_isblocked ?r - road)
  )
  (:functions (total-cost))
  (:constants road0 road1 road2 - road waypoint0 waypoint1 waypoint2 - waypoint)
  (:action sample_soil
    :parameters (?x - rover ?s - store ?p - waypoint)
    :precondition (and (at ?x ?p) (at_soil_sample ?p) (equipped_for_soil_analysis ?x) (store_of ?s ?x) (empty ?s))
    :effect (and (increase (total-cost) 1) (not (empty ?s)) (full ?s) (have_soil_analysis ?x ?p) (not (at_soil_sample ?p)))
  )
  (:action sample_rock
    :parameters (?x - rover ?s - store ?p - waypoint)
    :precondition (and (at ?x ?p) (at_rock_sample ?p) (equipped_for_rock_analysis ?x) (store_of ?s ?x) (empty ?s))
    :effect (and (increase (total-cost) 1) (not (empty ?s)) (full ?s) (have_rock_analysis ?x ?p) (not (at_rock_sample ?p)))
  )
  (:action drop
    :parameters (?x - rover ?y - store)
    :precondition (and (store_of ?y ?x) (full ?y))
    :effect (and (increase (total-cost) 1) (not (full ?y)) (empty ?y))
  )
  (:action calibrate
    :parameters (?r - rover ?i - camera ?t - objective ?w - waypoint)
    :precondition (and (equipped_for_imaging ?r) (calibration_target ?i ?t) (at ?r ?w) (visible_from ?t ?w) (on_board ?i ?r))
    :effect (and (increase (total-cost) 1) (calibrated ?i ?r))
  )
  (:action take_image
    :parameters (?r - rover ?p - waypoint ?o - objective ?i - camera ?m - mode)
    :precondition (and (calibrated ?i ?r) (on_board ?i ?r) (equipped_for_imaging ?r) (supports ?i ?m) (visible_from ?o ?p) (at ?r ?p))
    :effect (and (increase (total-cost) 1) (have_image ?r ?o ?m) (not (calibrated ?i ?r)))
  )
  (:action communicate_soil_data
    :parameters (?r - rover ?l - lander ?p - waypoint ?x - waypoint ?y - waypoint)
    :precondition (and (at ?r ?x) (at_lander ?l ?y) (have_soil_analysis ?r ?p) (visible ?x ?y) (available ?r) (channel_free ?l))
    :effect (and (increase (total-cost) 1) (communicated_soil_data ?p))
  )
  (:action communicate_rock_data
    :parameters (?r - rover ?l - lander ?p - waypoint ?x - waypoint ?y - waypoint)
    :precondition (and (at ?r ?x) (at_lander ?l ?y) (have_rock_analysis ?r ?p) (visible ?x ?y) (available ?r) (channel_free ?l))
    :effect (and (increase (total-cost) 1) (communicated_rock_data ?p))
  )
  (:action communicate_image_data
    :parameters (?r - rover ?l - lander ?o - objective ?m - mode ?x - waypoint ?y - waypoint)
    :precondition (and (at ?r ?x) (at_lander ?l ?y) (have_image ?r ?o ?m) (visible ?x ?y) (available ?r) (channel_free ?l))
    :effect (and (increase (total-cost) 1) (communicated_image_data ?o ?m))
  )
  (:action try-navigate-l0-l1
    :parameters (?x - rover)
    :precondition (and (can_traverse ?x waypoint0 waypoint1) (available ?x) (at ?x waypoint0) (visible waypoint0 waypoint1) (road_isunknown road0))
    :effect (and (increase (total-cost) 16) (not (road_isunknown road0)) (probabilistic 200/1000 (and (road_isblocked road0)) 800/1000 (and (road_isfree road0) (not (at ?x waypoint0)) (at ?x waypoint1))))
  )
  (:action navigate-l0-l1
    :parameters (?x - rover)
    :precondition (and (can_traverse ?x waypoint0 waypoint1) (available ?x) (at ?x waypoint0) (visible waypoint0 waypoint1) (road_isfree road0))
    :effect (and (increase (total-cost) 16) (not (at ?x waypoint0)) (at ?x waypoint1))
  )
  (:action try-navigate-l1-l0
    :parameters (?x - rover)
    :precondition (and (can_traverse ?x waypoint1 waypoint0) (available ?x) (at ?x waypoint1) (visible waypoint1 waypoint0) (road_isunknown road0))
    :effect (and (increase (total-cost) 16) (not (road_isunknown road0)) (probabilistic 200/1000 (and (road_isblocked road0)) 800/1000 (and (road_isfree road0) (not (at ?x waypoint1)) (at ?x waypoint0))))
  )
  (:action navigate-l1-l0
    :parameters (?x - rover)
    :precondition (and (can_traverse ?x waypoint1 waypoint0) (available ?x) (at ?x waypoint1) (visible waypoint1 waypoint0) (road_isfree road0))
    :effect (and (increase (total-cost) 16) (not (at ?x waypoint1)) (at ?x waypoint0))
  )
  (:action try-navigate-l0-l2
    :parameters (?x - rover)
    :precondition (and (can_traverse ?x waypoint0 waypoint2) (available ?x) (at ?x waypoint0) (visible waypoint0 waypoint2) (road_isunknown road1))
    :effect (and (increase (total-cost) 5) (not (road_isunknown road1)) (probabilistic 200/1000 (and (road_isblocked road1)) 800/1000 (and (road_isfree road1) (not (at ?x waypoint0)) (at ?x waypoint2))))
  )
  (:action navigate-l0-l2
    :parameters (?x - rover)
    :precondition (and (can_traverse ?x waypoint0 waypoint2) (available ?x) (at ?x waypoint0) (visible waypoint0 waypoint2) (road_isfree road1))
    :effect (and (increase (total-cost) 5) (not (at ?x waypoint0)) (at ?x waypoint2))
  )
  (:action try-navigate-l2-l0
    :parameters (?x - rover)
    :precondition (and (can_traverse ?x waypoint2 waypoint0) (available ?x) (at ?x waypoint2) (visible waypoint2 waypoint0) (road_isunknown road1))
    :effect (and (increase (total-cost) 5) (not (road_isunknown road1)) (probabilistic 200/1000 (and (road_isblocked road1)) 800/1000 (and (road_isfree road1) (not (at ?x waypoint2)) (at ?x waypoint0))))
  )
  (:action navigate-l2-l0
    :parameters (?x - rover)
    :precondition (and (can_traverse ?x waypoint2 waypoint0) (available ?x) (at ?x waypoint2) (visible waypoint2 waypoint0) (road_isfree road1))
    :effect (and (increase (total-cost) 5) (not (at ?x waypoint2)) (at ?x waypoint0))
  )
  (:action try-navigate-l1-l2
    :parameters (?x - rover)
    :precondition (and (can_traverse ?x waypoint1 waypoint2) (available ?x) (at ?x waypoint1) (visible waypoint1 waypoint2) (road_isunknown road2))
    :effect (and (increase (total-cost) 2) (not (road_isunknown road2)) (probabilistic 200/1000 (and (road_isblocked road2)) 800/1000 (and (road_isfree road2) (not (at ?x waypoint1)) (at ?x waypoint2))))
  )
  (:action navigate-l1-l2
    :parameters (?x - rover)
    :precondition (and (can_traverse ?x waypoint1 waypoint2) (available ?x) (at ?x waypoint1) (visible waypoint1 waypoint2) (road_isfree road2))
    :effect (and (increase (total-cost) 2) (not (at ?x waypoint1)) (at ?x waypoint2))
  )
  (:action try-navigate-l2-l1
    :parameters (?x - rover)
    :precondition (and (can_traverse ?x waypoint2 waypoint1) (available ?x) (at ?x waypoint2) (visible waypoint2 waypoint1) (road_isunknown road2))
    :effect (and (increase (total-cost) 2) (not (road_isunknown road2)) (probabilistic 200/1000 (and (road_isblocked road2)) 800/1000 (and (road_isfree road2) (not (at ?x waypoint2)) (at ?x waypoint1))))
  )
  (:action navigate-l2-l1
    :parameters (?x - rover)
    :precondition (and (can_traverse ?x waypoint2 waypoint1) (available ?x) (at ?x waypoint2) (visible waypoint2 waypoint1) (road_isfree road2))
    :effect (and (increase (total-cost) 2) (not (at ?x waypoint2)) (at ?x waypoint1))
  )
)